package com.muyu.server.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.domain.SysCarFaultLog;
import com.muyu.server.mapper.SysCarFaultLogMapper;
import com.muyu.server.service.SysCarFaultLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 车辆故障记录 业务层
 * @author 袁子龙
 * @package: com.muyu.breakdown.service.impl
 * @name: sysCarFaultLogServiceImpl
 * @date: 2024/9/22 21:07
 */
@Service
public class SysCarFaultLogServiceImpl extends ServiceImpl<SysCarFaultLogMapper, SysCarFaultLog> implements SysCarFaultLogService {


    @Autowired
    private SysCarFaultLogMapper sysCarFaultLogMapper;

    @Override
    public List<SysCarFaultLog> selectSysCarFaultLogList(SysCarFaultLog sysCarFaultLog) {

        return sysCarFaultLogMapper.selectSysCarFaultLogList(sysCarFaultLog);
    }

    /**
     * 只展示忽略的数据
     * @param sysCarFaultLog
     * @return
     */
    @Override
    public List<SysCarFaultLog> listStatusIgnore(SysCarFaultLog sysCarFaultLog) {

        return sysCarFaultLogMapper.listStatusIgnore(sysCarFaultLog);
    }

    /**
     * 只展示处理中的数据
     * @param sysCarFaultLog
     * @return
     */
    @Override
    public List<SysCarFaultLog> listStatusProcess(SysCarFaultLog sysCarFaultLog) {

        return sysCarFaultLogMapper.listStatusProcess(sysCarFaultLog);
    }

    //只展示已解决的数据
    @Override
    public List<SysCarFaultLog> listStatusSolve(SysCarFaultLog sysCarFaultLog) {
        return sysCarFaultLogMapper.listStatusSolve(sysCarFaultLog);
    }



}
